summaryrefslogtreecommitdiff
path: root/executer/exsystem.c
diff options
context:
space:
mode:
Diffstat (limited to 'executer/exsystem.c')
-rw-r--r--executer/exsystem.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/executer/exsystem.c b/executer/exsystem.c
index f43ef215527f..8f4ccfe37140 100644
--- a/executer/exsystem.c
+++ b/executer/exsystem.c
@@ -280,19 +280,19 @@ AcpiExSystemDoStall (
/*******************************************************************************
*
- * FUNCTION: AcpiExSystemDoSuspend
+ * FUNCTION: AcpiExSystemDoSleep
*
* PARAMETERS: HowLong - The amount of time to suspend,
* in milliseconds
*
* RETURN: None
*
* DESCRIPTION: Suspend running thread for specified amount of time.
*
******************************************************************************/
ACPI_STATUS
-AcpiExSystemDoSuspend (
+AcpiExSystemDoSleep (
UINT64 HowLong)
{
ACPI_FUNCTION_ENTRY ();
@@ -280,19 +280,19 @@ AcpiExSystemDoStall (
*
- * PARAMETERS: HowLong - The amount of time to suspend,
+ * PARAMETERS: HowLong - The amount of time to sleep,
* in milliseconds
*
@@ -280,19 +280,19 @@ AcpiExSystemDoStall (
* RETURN: None
*
- * DESCRIPTION: Suspend running thread for specified amount of time.
+ * DESCRIPTION: Sleep the running thread for specified amount of time.
*
******************************************************************************/